@@ -2,24 +2,27 @@ import math
 from typing import Optional
 
 from PyQt5.QtCore import Qt, QRect, QPoint, QPointF
-from PyQt5.QtGui import QPainter, QBrush, QPixmap, QImage, QColor, QPolygonF, QPalette
+from PyQt5.QtGui import (
+    QPainter, QBrush, QPixmap, QImage, QColor, QPolygonF, QPalette,
+    QPainterPath, QGuiApplication,
+)
 from PyQt5.QtWidgets import QWidget
 
-from feeluown.gui.helpers import random_solarized_color, painter_save
+from feeluown.gui.helpers import random_solarized_color, painter_save, IS_MACOS
 
 
-class PixmapDrawer:
-    """Draw pixmap on a widget with radius.
-
-    The pixmap will be scaled to the width of the widget.
+class SizedPixmapDrawer:
     """
-    def __init__(self, img, widget: QWidget, radius: int = 0):
-        """
-        :param widget: a object which has width() and height() method.
-        """
-        self._widget_last_width = widget.width()
-        self._widget = widget
+    Draw pixmap on a specific rect (on a fixed area).
+
+    Note that if device_pixel_ratio is not properly set, the drawed image
+    quality may be poor.
+    """
+    def __init__(self, img: Optional[QImage], rect: QRect, radius: int = 0):
+        self._rect = rect
+        self._img_old_width = rect.width()
         self._radius = radius
+        self._device_pixel_ratio = QGuiApplication.instance().devicePixelRatio()
 
         if img is None:
             self._color = random_solarized_color()
@@ -28,8 +31,20 @@ class PixmapDrawer:
         else:
             self._img = img
             self._color = None
-            new_img = img.scaledToWidth(self._widget_last_width, Qt.SmoothTransformation)
+            new_img = self._scale_image(img)
             self._pixmap = QPixmap(new_img)
+            self._pixmap.setDevicePixelRatio(self._device_pixel_ratio)
+
+    def _scale_image(self, img: QImage) -> QImage:
+        return img.scaledToWidth(int(self._img_old_width * self._device_pixel_ratio),
+                                 Qt.SmoothTransformation)
+
+    def get_radius(self):
+        return self._radius if self._radius >= 1 else \
+            self.get_rect().width() * self._radius
+
+    def get_rect(self):
+        return self._rect
 
     @classmethod
     def from_img_data(cls, img_data, *args, **kwargs):
@@ -43,57 +58,72 @@ class PixmapDrawer:
     def get_pixmap(self) -> Optional[QPixmap]:
         return self._pixmap
 
-    def maybe_update_pixmap(self):
-        if self._widget.width() != self._widget_last_width:
-            self._widget_last_width = self._widget.width()
-            assert self._img is not None
-            new_img = self._img.scaledToWidth(self._widget_last_width,
-                                              Qt.SmoothTransformation)
-            self._pixmap = QPixmap(new_img)
-
-    def draw(self, painter):
-        painter.save()
-        painter.setRenderHint(QPainter.Antialiasing)
-        painter.setRenderHint(QPainter.SmoothPixmapTransform)
-        if self._pixmap is None:
-            self._draw_random_color(painter)
-        else:
-            self._draw_pixmap(painter)
-        painter.restore()
-
-    def _get_radius(self):
-        return self._radius if self._radius >= 1 else self._widget.width() * self._radius
+    def draw(self, painter: QPainter):
+        with painter_save(painter):
+            if self._pixmap is None:
+                self._draw_random_color(painter)
+            else:
+                self._draw_pixmap(painter)
 
     def _draw_random_color(self, painter: QPainter):
         brush = QBrush(self._color)
         painter.setBrush(brush)
         painter.setPen(Qt.NoPen)
-        rect = self._widget.rect()
-        if self._radius == 0:
+        rect = self.get_rect()
+        radius = self.get_radius()
+        if radius == 0:
             painter.drawRect(rect)
         else:
-            radius = self._get_radius()
             painter.drawRoundedRect(rect, radius, radius)
 
     def _draw_pixmap(self, painter: QPainter):
         assert self._pixmap is not None
 
-        self.maybe_update_pixmap()
         brush = QBrush(self._pixmap)
         painter.setBrush(brush)
         painter.setPen(Qt.NoPen)
-        radius = self._radius
-        size = self._pixmap.size()
-        y = (size.height() - self._widget.height()) // 2
-        painter.save()
-        painter.translate(0, -y)
-        rect = QRect(0, 0, self._widget.width(), size.height())
-        if radius == 0:
-            painter.drawRect(rect)
-        else:
-            radius = radius if self._radius >= 1 else self._widget.width() * self._radius
-            painter.drawRoundedRect(rect, radius, radius)
-        painter.restore()
+        radius = self.get_radius()
+        size = self._pixmap.size() / self._pixmap.devicePixelRatio()
+        target_rect = self.get_rect()
+        y = (size.height() - target_rect.height()) // 2
+        with painter_save(painter):
+            painter.translate(target_rect.x(), target_rect.y())
+            painter.translate(0, -y)
+            rect = QRect(0, 0, target_rect.width(), size.height())
+            if radius == 0:
+                painter.drawRect(rect)
+            else:
+                painter.drawRoundedRect(rect, radius, radius)
+
+
+class PixmapDrawer(SizedPixmapDrawer):
+    """Draw pixmap on a widget with radius.
+
+    The pixmap will be scaled to the width of the widget.
+
+    TODO: rename this drawer to WidgetPixmapDrawer?
+    """
+    def __init__(self, img, widget: QWidget, radius: int = 0):
+        """
+        :param widget: a object which has width() and height() method.
+        """
+        super().__init__(img, widget.rect(), radius)
+        self._widget = widget
+
+    def get_rect(self):
+        return self._widget.rect()
+
+    def maybe_update_pixmap(self):
+        if self._widget.width() != self._img_old_width:
+            self._img_old_width = self._widget.width()
+            assert self._img is not None
+            new_img = self._img.scaledToWidth(self._img_old_width,
+                                              Qt.SmoothTransformation)
+            self._pixmap = QPixmap(new_img)
+
+    def _draw_pixmap(self, painter: QPainter):
+        self.maybe_update_pixmap()
+        super()._draw_pixmap(painter)
 
 
 class AvatarIconDrawer:
@@ -103,7 +133,7 @@ class AvatarIconDrawer:
 
         self.fg_color = fg_color
 
-    def draw(self, painter):
+    def draw(self, painter: QPainter):
         pen = painter.pen()
         pen.setWidthF(1.5)
         painter.setPen(pen)
@@ -391,3 +421,78 @@ class VolumeIconDrawer:
             painter.setPen(pen)
             for line in disabled_lines:
                 painter.drawLine(*line)
+
+
+class FireIconDrawer:
+    def __init__(self, length, padding):
+        self.length = length
+        self.padding = padding
+
+    def paint(self, painter):
+        # flake8: noqa: E501
+        # The following path is copied from a SVG file.
+        path = QPainterPath()
+        path.moveTo(495.466219, 1024)
+        path.cubicTo(256.335982, 1024, 86.993753, 856.408725, 86.993753, 625.658051)
+        path.cubicTo(86.993753, 503.091298, 159.658328, 370.019367, 162.785031, 364.641439)
+        path.cubicTo(169.163505, 353.385309, 181.670316, 347.006835, 194.552333, 348.507652)
+        path.cubicTo(207.434349, 350.258606, 217.689934, 359.638714, 221.31691, 372.020458)
+        path.cubicTo(221.567046, 372.645799, 241.202876, 447.5616, 266.966908, 488.70901)
+        path.cubicTo(284.226308, 516.474132, 301.98598, 535.85969, 321.746742, 549.617182)
+        path.cubicTo(308.364454, 490.83501, 298.108868, 402.411852, 314.742928, 311.862536)
+        path.cubicTo(360.392654, 63.226735, 554.248234, 3.569244, 562.502729, 1.19295)
+        path.cubicTo(573.133519, -1.808685, 584.639785, 0.942814, 592.769213, 8.4469)
+        path.cubicTo(600.898641, 15.950986, 603.398641, 27.446525, 601.147415, 38.327452)
+        path.cubicTo(600.897279, 40.078406, 568.504541, 215.423167, 636.416528, 363.87902)
+        path.cubicTo(642.544866, 377.386376, 651.174556, 393.019891, 660.429596, 408.778474)
+        path.cubicTo(663.056026, 386.266213, 667.43341, 364.379293, 673.561748, 342.492373)
+        path.cubicTo(698.575371, 254.44442, 762.985451, 224.303004, 765.736949, 223.17739)
+        path.cubicTo(776.492807, 218.424802, 788.999618, 220.675301, 798.254659, 227.929252)
+        path.cubicTo(807.634768, 235.183203, 812.012152, 247.189742, 809.885993, 258.946145)
+        path.cubicTo(809.510789, 261.197371, 800.505884, 321.105, 851.158472, 406.151318)
+        path.cubicTo(896.071545, 482.827503, 909.078629, 532.479545, 909.078629, 628.156654)
+        path.cubicTo(908.953561, 858.782259, 734.358471, 1026.248466, 495.466219, 1026.248466)
+        path.closeSubpath()
+
+        # Calculate scaling factor
+        scale_factor = 1024 / (self.length - 2 * self.padding)
+        painter_sf = 1 / scale_factor
+
+        # Scale and translate the path
+        transform = painter.transform()
+        transform.scale(painter_sf, painter_sf)
+        transform.translate(self.padding * scale_factor, self.padding * scale_factor)
+
+        with painter_save(painter):
+            painter.setTransform(transform)
+
+            # Set the brush and pen
+            pen = painter.pen()
+            pen.setWidthF(1.5 * scale_factor)
+            painter.setPen(pen)
+
+            # Draw the fire shape
+            painter.drawPath(path)
+
+
+class EmojiIconDrawer:
+    def __init__(self, emoji: str, length: int, padding: int):
+        self._emoji = emoji
+        self._length = length
+        self._padding = padding
+
+        self._emoji_width = self._length - 2 * self._padding
+
+    def paint(self, painter: QPainter):
+        width = self._emoji_width
+        with painter_save(painter):
+            painter.translate(self._padding, self._padding)
+            font = painter.font()
+            if IS_MACOS:
+                # -4 works well on macOS when length is in range(30, 200)
+                font.setPixelSize(width - 4)
+            else:
+                # -1 works well on KDE when length is in range(30, 200)
+                font.setPixelSize(width - (self._length//20))
+            painter.setFont(font)
+            painter.drawText(0, 0, width, width, Qt.AlignHCenter | Qt.AlignVCenter, self._emoji)
