@@ -44,27 +44,39 @@ def default_score_fn(origin, standby):
     def duration_ms_to_duration(ms):
         if not ms:  # ms is empty
             return 0
-        m, s = ms.split(':')
-        return int(m) * 60 + int(s)
+        parts = ms.split(':')
+        assert len(parts) in (2, 3), f'invalid duration format: {ms}'
+        if len(parts) == 3:
+            h, m, s = parts
+        else:
+            m, s = parts
+            h = 0
+        return int(h) * 3600 + int(m) * 60 + int(s)
 
     score = FULL_SCORE
-    if origin.artists_name_display != standby.artists_name_display:
+    if origin.artists_name != standby.artists_name:
         score -= 3
-    if origin.title_display != standby.title_display:
+    if origin.title != standby.title:
         score -= 2
-    if origin.album_name_display != standby.album_name_display:
+    if origin.album_name != standby.album_name:
         score -= 2
 
-    origin_duration = duration_ms_to_duration(origin.duration_ms_display)
-    standby_duration = duration_ms_to_duration(standby.duration_ms_display)
+    if isinstance(origin, SongModel):
+        origin_duration = origin.duration
+    else:
+        origin_duration = duration_ms_to_duration(origin.duration_ms)
+    if isinstance(standby, SongModel):
+        standby_duration = standby.duration
+    else:
+        standby_duration = duration_ms_to_duration(standby.duration_ms)
     if abs(origin_duration - standby_duration) / max(origin_duration, 1) > 0.1:
         score -= 3
 
     # Debug code for score function
-    # print(f"{score}\t('{standby.title_display}', "
-    #       f"'{standby.artists_name_display}', "
-    #       f"'{standby.album_name_display}', "
-    #       f"'{standby.duration_ms_display}')")
+    # print(f"{score}\t('{standby.title}', "
+    #       f"'{standby.artists_name}', "
+    #       f"'{standby.album_name}', "
+    #       f"'{standby.duration_ms}')")
     return score
 
 
@@ -298,6 +310,21 @@ class Library:
                 raise MediaNotFound('provider returns empty media')
         return media
 
+    def song_get_web_url(self, song: BriefSongModel) -> str:
+        """Get song web url
+
+        :raises ResourceNotFound: provider/song/web_url is not found
+        :raises ProviderIOError: provider raises error during get_web_url
+
+        .. versionadded:: 4.1.8
+        """
+        provider = self.get(song.source)
+        if provider is None:
+            raise ResourceNotFound(f'provider({song.source}) not found')
+        if isinstance(provider, SupportsSongWebUrl):
+            return provider.song_get_web_url(song)
+        raise ResourceNotFound(reason=ResourceNotFound.Reason.not_supported)
+
     def song_prepare_mv_media(self, song: BriefSongModel, policy) -> Media:
         """
 
