@@ -1,8 +1,10 @@
 from .metadata import MetadataFields, Metadata
-from .playlist import PlaybackMode
+from .playlist import PlaybackMode, PlaylistRepeatMode, PlaylistShuffleMode, \
+    PlaylistPlayModelStage
 from .base_player import State
 from .mpvplayer import MpvPlayer as Player
 from .playlist import PlaylistMode, Playlist
+from .metadata_assembler import MetadataAssembler
 from .fm import FM
 from .radio import SongRadio
 from .lyric import LiveLyric, parse_lyric_text, Line as LyricLine, Lyric
@@ -12,6 +14,9 @@ from .delegate import PlayerPositionDelegate
 
 __all__ = (
     'PlaybackMode',
+    'PlaylistRepeatMode',
+    'PlaylistShuffleMode',
+    'PlaylistPlayModelStage',
     'State',
 
     'FM',
@@ -24,6 +29,7 @@ __all__ = (
 
     'Metadata',
     'MetadataFields',
+    'MetadataAssembler',
 
     'LiveLyric',
     'parse_lyric_text',
