@@ -67,7 +67,8 @@ class MpvPlayer(AbstractPlayer):
                                b'Mozilla/5.0 (Windows NT 10.0; Win64; x64)')
 
         #: if video_format changes to None, there is no video available
-        self.video_format_changed = Signal()
+        self.video_format_changed = Signal()  # Optional[str]
+        self.audio_bitrate_changed = Signal()  # Optional[int], for example: 128001
 
         self._mpv.observe_property(
             'time-pos',
@@ -81,6 +82,10 @@ class MpvPlayer(AbstractPlayer):
             'video-format',
             lambda name, vformat: self._on_video_format_changed(vformat)
         )
+        self._mpv.observe_property(
+            'audio-bitrate',
+            lambda name, bitrate: self._on_audio_bitrate_changed(bitrate)
+        )
         # self._mpv.register_event_callback(lambda event: self._on_event(event))
         self._mpv._event_callbacks.append(self._on_event)
         logger.debug('Player initialize finished.')
@@ -259,6 +264,13 @@ class MpvPlayer(AbstractPlayer):
         super(MpvPlayer, MpvPlayer).volume.__set__(self, value)
         self._mpv.volume = self.volume
 
+    @property
+    def audio_bitrate(self):
+        """
+        .. versionadded: 4.1.4
+        """
+        return self._mpv.audio_bitrate
+
     @property
     def video_format(self):
         return self._video_format
@@ -289,6 +301,9 @@ class MpvPlayer(AbstractPlayer):
     def _on_video_format_changed(self, vformat):
         self.video_format = vformat
 
+    def _on_audio_bitrate_changed(self, bitrate):
+        self.audio_bitrate_changed.emit(bitrate)
+
     def _on_event(self, event):
         event_id = event['event_id']
         if event_id == MpvEventID.END_FILE:
