@@ -44,7 +44,7 @@ class PreemptiveTaskSpec:
             self._mgr.loop.call_soon_threadsafe(self._task.cancel)
         self._task = None
 
-    def bind_coro(self, coro):
+    def bind_coro(self, coro) -> asyncio.Task:
         """run the coroutine and bind the task
 
         it will cancel the previous task if exists
@@ -60,7 +60,7 @@ class PreemptiveTaskSpec:
             self._task.add_done_callback(self._cb)
         return self._task
 
-    def bind_blocking_io(self, func, *args):
+    def bind_blocking_io(self, func, *args) -> asyncio.Task:
         """run blocking io func in a thread executor, and bind the task
 
         it will cancel the previous task if exists
@@ -129,12 +129,14 @@ class TaskManager:
         if not name:
             name = get_fn_name(afn)
         task_spec = self.get_or_create(name)
+        task_spec.disable_default_cb()
         return task_spec.bind_coro(afn(*args))
 
     def run_fn_preemptive(self, fn, *args, name=''):
         if not name:
             name = get_fn_name(fn)
         task_spec = self.get_or_create(name)
+        task_spec.disable_default_cb()
         return task_spec.bind_blocking_io(fn, *args)
 
 
